
# Metric reference

For metrics, the *Receives* field in the function descriptions is used to document what columns are assumed to be in the DriveData objects processed by the metric. 

::: pydre.metrics.common
    options:
        show_root_heading: false
        filters: ["!^_"]
